@@ -125,7 +125,7 @@ atspi_register_keystroke_listener (AtspiDeviceListener  *listener,
 					 GArray             *key_set,
 					 AtspiKeyMaskType         modmask,
 					 AtspiKeyEventMask        event_types,
-					 AtspiKeyListenerSyncType sync_type, GError **error)
+					 gint sync_type, GError **error)
 {
   GArray *d_key_set;
   gchar *path = _atspi_device_listener_get_path (listener);
